# metrax

`metrax` is an official JAX metrics library.

## Installation

Install the package by installing the PyPi release.

```
pip install google-metrax
```

## Development

Develop the docs locally:

```
sphinx-build ./docs /tmp/metrax_docs
python -m http.server --directory /tmp/metrax_docs
```
